#
# spec file for package rss2email
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
Name:           rss2email
Version:        3.14
Release:        1.6
Summary:        Receive RSS feeds by email
License:        GPL-2.0-only OR GPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/rss2email/rss2email
Source:         https://github.com/rss2email/rss2email/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module feedparser >= 6.0.0}
BuildRequires:  %{python_module html2text >= 3.0.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-generators
BuildRequires:  python-rpm-macros
Requires:       python-feedparser >= 6.0.0
Requires:       python-html2text >= 3.0.1
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%{?python_enable_dependency_generator}
%python_subpackages

%description
Lets users receive news from RSS feeds in email. Intended to be run from
a crontab, watches RSS feeds and sends formatted email messages for new
items.

%prep
%autosetup

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/r2e
install -Dm644 r2e.1 %{buildroot}%{_mandir}/man1/r2e.1
%python_clone -a %{buildroot}%{_mandir}/man1/r2e.1

%check
pushd test
%pyunittest --verbose
popd

%post
%python_install_alternative r2e r2e.1

%postun
%python_uninstall_alternative r2e r2e.1

%files %{python_files}
%license COPYING
%doc AUTHORS CHANGELOG README.rst
%dir %{python_sitelib}/rss2email
%dir %{python_sitelib}/rss2email/__pycache__
%dir %{python_sitelib}/rss2email/post_process
%dir %{python_sitelib}/rss2email/post_process/__pycache__
%{python_sitelib}/rss2email/*py
%{python_sitelib}/rss2email/post_process/*py
%{python_sitelib}/rss2email-%{version}-py*.egg-info
%pycache_only %{python_sitelib}/rss2email/__pycache__/*
%pycache_only %{python_sitelib}/rss2email/post_process/__pycache__/*
%python_alternative %{_bindir}/r2e
%python_alternative %{_mandir}/man1/r2e.1%{?ext_man}

%changelog
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 3.14:
  * New `digest-type` configuration adds optional more widely supported `multipart/mixed` format
  * New argument `--only-new` on the `add` command to ignore entries in feed
    when added, so only new entries will be sent.
  * Fix exception when parsing a feed with a linebreak in its title
  * Add a new `subject-format` setting, customise the subject line
  * Removed '$' interpolation in config file to allow URLs containing dollar
    signs. Interpolation was not fully supported, and the placeholder would not
    survive a second save. Config files with ${...} placeholders will need to be
    manually edited after upgrading, or a save forced by adding and removing a fake
    feed before upgrading.
  * Fix default HTTP User-Agent to use `rss2email` instead of `feedparser`, and
    fix `user-agent` setting to consistently apply to both outgoing emails and
    HTTP requests. This introduces a couple of potentially breaking changes:
    o Configurations that came to rely on the `feedparser` UA string should adjust to the updated UA string going forward.
    o Configurations that came to rely on the unintended behaviour, that
    configuring the User-Agent header in emails does not affect HTTP requests,
    should use a custom `post-process` hook instead.
* Tue Apr 26 2022 Steve Kowalik <steven.kowalik@suse.com>
- No longer skip python310, feedparser is now available.
* Sat Feb  5 2022 Benjamin Greiner <code@bnavigator.de>
- Skip python310: no sgmlli3k and thus no feedparser for Python3.10
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 3.13.1:
  * Fix crash on html-mail entries with no URL
* Mon Apr 12 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * removed patch rss2email-3.12.2-feedparser-6.patch (fixed upstream)
  * fix requirements
- update to version 13.3:
  * Switch to feedparser 6
  * Switch to poetry instead of requirements.txt
  * Make the `verbose` flag in the config file actually have an
    impact, and have it default to `info
  * Improve log messages
  * Remove documentation of `smtp-ssl-protocol` as this option was
    dropped in 2016
  * Stop forging SMTP and sendmail envelope sender (#134)
  * Add sendmail_config option
  * Upgraded to feedparser v6.0
    (https://github.com/kurtmckee/feedparser/)
  * Drop support for Python 3.5, add support for Python 3.9
  * Log sendmail output
  * Support multipart/alternative emails with both HTML and plain text
    parts with option `multipart-html`
  * Add inline-links option, allowing links to be sent to the bottom
    of the paragraph
  * Add wrap-links option, preventing links from be wrapped over
    multiple lines
  * Stop looking in $XDG_DATA_DIRS for the database, and only look in
    $XDG_DATA_HOME
  * Warnings about HTTP content-type being unexpected now properly
    display
  * Make the proxy parameter also affect https connections
  * Add a --clean argument on the run command to reduce the database
    size
  * Set body element attribute dir=auto in HTML mail
  * Store the lock file in XDG_RUNTIME_DIR instead of /tmp
* Mon Mar 29 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * update patch
  * add __pycache__ files
  * update to newer python macros
  * skip python2
- update to version 3.12.3:
  * *Improve log messages
  * Remove documentation of `smtp-ssl-protocol` as this option was
    dropped in 2016
  * Stop forging SMTP and sendmail envelope sender (#134)
  * Add sendmail_config option
  * Fix verbose configuration setting
  * Upgraded to feedparser v6.0
    (https://github.com/kurtmckee/feedparser/)
  * Drop support for Python 3.5
  * Log sendmail output
  * Support multipart/alternative emails with both HTML and plain text
    parts with option `multipart-html`
  * Add inline-links option, allowing links to be sent to the bottom
    of the
  * paragraph
  * Add wrap-links option, preventing links from be wrapped over
    multiple lines
  * Stop looking in $XDG_DATA_DIRS for the database, and only look in
  * $XDG_DATA_HOME
  * Warnings about HTTP content-type being unexpected now properly
    display
  * Make the proxy parameter also affect https connections
  * Add a --clean argument on the run command to reduce the database
    size
* Sun Nov  8 2020 Andreas Stieger <andreas.stieger@gmx.de>
- fix failure with Feedparser 6 [boo#1178085]
  adding rss2email-3.12.2-feedparser-6.patch from upstream
- clean up spec file to current python Macros, run tests
* Thu Sep  3 2020 Arun Persaud <arun@gmx.de>
- update to version 3.12.2:
  * Fix bug `AttributeError: 'NoneType' object has no attribute
    'close'` (#126)
- changes from version 3.12.1 :
  * Fix calling opmlexport without arguments
- changes from version 3.12:
  * Drop support for EOL Python 3.4, add support for Python 3.8
  * Add List_ID and List_Post headers to the generated emails
  * Add a new `reply-changes` setting
  * Improve configurability of text wrapping for the emails
  * Use `platform.node()` instead of "dev.null.invalid" in
    "Message-ID" header
  * Improve locking support for when multiple rss2email instances are
    run in parallel
  * Fix handling of __VERSION__ and __URL__ in user-agent strings
  * Fix opmlexport
* Sun Dec 29 2019 Arun Persaud <arun@gmx.de>
- update to version 3.11:
  * Add new `user-agent` attribute for configuring email User-Agent
* Sat Sep 21 2019 Arun Persaud <arun@gmx.de>
- update to version 3.10:
  * Catch and warn for invalid Content-Types
  * Add a manually extracted list of config options to r2e.1
  * Add a redirect post-process module
  * Follow symlinks of datafiles
  * Add zsh completion
  * Add support for maildir
  * Fix `r2e new` overwriting an existing config
  * Add new `feed-name` and `feed-url` attributes for the
    `name-format` setting
  * Change logging format
  * Allow multiple SMTP recipients
  * Fix SMTP security issues
  * Fix test suite
  * Drop support for Python 3.2 and 3.3
  * Remove `__contributors__` from the `rss2email` module
  * Stop using deprecated `html2text.unescape`
  * Fix locking issues when data file is on NFS
  * Add `same-server-fetch-interval` setting for rate-limiting fetches
    to a server
  * Update setup.py to setuptools
* Wed Apr  5 2017 jmatejek@suse.com
- switch requires from outdated python3-distribute to setuptools
* Tue Sep  2 2014 arun@gmx.de
- update to v3.9 (2014-09-01)
  * Catch and error out if a user adds a feed with a duplicate name.
  * Split sender into both sendmail's -F and -f.
  * Fix an error with SMTPConnectionError inheritance order ("does not
    take keyword arguments").
  * Add a new `smtp-ssl-protocol` setting, to select acceptable
    protocols for SMTP connections.
  * Fix non-compliant User-Agent header for HTTP/1.1.
  * Fix an error in the NoToEmailAddress invocation.
  * Add a new 'trust-link' setting, to prefer the 'link' attribute over
    the 'id' attribute for identifying entries.
* Sun Feb  2 2014 cfarrell@suse.com
- license update: GPL-2.0 or GPL-3.0
  This is a dual license of either GPL-2.0 or GPL-3.0. It does not allow
  updating to beyond GPL-3.0
* Mon Jan 20 2014 arun@gmx.de
- updated to v3.8 (2014-01-18)
  * Sluggify feed names on opmlimport.
  * Allow Unicode letters and digits in feed names, instead of just ASCII lettters and digits.
* Fri Oct 11 2013 arun@gmx.de
- updated to version 3.7
  * Fix fallback for titles that contain malformed HTML [1].
  * Fix atomic saves to avoid garbling config and data files if the
    disk is full [2].  Reported by Etienne Millon [3,4].
  * Convert the `friendly-name` boolean to the new `name-format`
    setting.  This allow users to customize how the friendly name is
    constructed [5].  Requested by Joey Hess [6,7].
  * Demote guessed encodings logs from 'error' to 'warning' [8].
    Patch by J. Lewis Muir [9,10].
  [1]: http://thread.gmane.org/gmane.mail.rss2email/183
  [2]: http://thread.gmane.org/gmane.mail.rss2email/182
  [3]: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=724671
  [4]: https://github.com/wking/rss2email/issues/22
  [5]: http://thread.gmane.org/gmane.mail.rss2email/177
  [6]: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=722009
  [7]: https://github.com/wking/rss2email/issues/19
  [8]: http://thread.gmane.org/gmane.mail.rss2email/178
  [9]: https://github.com/wking/rss2email/pull/18
  [10]: https://github.com/wking/rss2email/pull/20
* Fri Sep 20 2013 arun@gmx.de
- updated to version 3.6
  Changes since 3.5 (from CHANGELOG)
  v3.6 (2013-09-09)
  * Fix missing port argument for IMAPAuthenticationError.
  * Fix `<div id="entry>` syntax error in HTML mail.
* Thu Jun  6 2013 arun@gmx.de
- updated to version 3.5
  Changes since 3.4 (from CHANGELOG)
  v3.5 (2013-06-05)
  * Added digest generation and post-processing hooks.
  * Fix html2text configuration (ignored since 2012-10-04).
  * Fix opmlexport crash due to orphaned feed data.
  * Use feed names in OPML 'text' attributes.
* Tue May 14 2013 arun@gmx.de
- updated to version 3.4
  Changes since 3.3 (from CHANGELOG)
  v3.4 (2013-05-14)
  * Added post-processing hooks for user-specified message manipulation.
  * Added settings for IMAP delivery. The old `use-smtp` boolean has
    been replaced by a new `email-protocol` setting. Non-IMAP users
    should adjust their configuration to set `email-protocol`
    to either `sendmail` or `smtp`.
* Sun Apr 14 2013 arun@gmx.de
- updated to version 3.3
  Changes since 3.2 (from CHANGELOG):
  v3.3 (2013-04-13)
  * Fix SMTP message submission logic.
  * Fix error inheritence (super() calls).
  * Convert html2text parsing errors to `ProcessingError`s.
  * Cleanup html2text error handling.
  * Drop Google Reader rel-via manipulation.
  * Drop the wrapping <table> elements from HTML mail
* Thu Mar 14 2013 arun@gmx.de
- updated to verson 3.2
  Changes since 3.1 (from the CHANGELOG):
  * Use extended interpolation in configuration files, to allow percent
  signs (%%).
  * Added .as_string() fallback to email flattening (only used if
  `use-smtp = False` and `use-8bit = True`).
  * Added sendmail configuration option.  Change this if you want to use
  an alternative, sendmail-compatible mailer.
* Sun Mar  3 2013 arun@gmx.de
- added some missing dependencies: python3, python3-xml,
  python3-feedparser, python3-html2text
* Fri Feb 15 2013 arun@gmx.de
- update to version 3.1, use tar.gz instead of zip
* Fri Feb 15 2013 arun@gmx.de
- fixed spec file according to comments on pull request
  * removed double install of doc files
  * don't zip man page
* Wed Jan 23 2013 arun@gmx.de
- initial version from current git (933dc46f6af3fb5473da93e02c9a90c1e4b4ae5f)
